@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*  GMime
- *  Copyright (C) 2000-2009 Jeffrey Stedfast
+ *  Copyright (C) 2000-2010 Jeffrey Stedfast
  *
  *  This library is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU Lesser General Public License
@@ -109,7 +109,38 @@ g_mime_init (guint32 flags)
 	gmime_error_quark = g_quark_from_static_string ("gmime");
 	
 	/* register our GObject types with the GType system */
+	g_mime_cipher_context_get_type ();
+#ifdef ENABLE_CRYPTOGRAPHY
+	g_mime_gpg_context_get_type ();
+#endif
+	
+	g_mime_filter_get_type ();
+	g_mime_filter_basic_get_type ();
+	g_mime_filter_best_get_type ();
+	g_mime_filter_charset_get_type ();
+	g_mime_filter_crlf_get_type ();
+	g_mime_filter_enriched_get_type ();
+	g_mime_filter_from_get_type ();
+	g_mime_filter_gzip_get_type ();
+	g_mime_filter_html_get_type ();
+	g_mime_filter_md5_get_type ();
+	g_mime_filter_strip_get_type ();
+	g_mime_filter_windows_get_type ();
+	g_mime_filter_yenc_get_type ();
+	
+	g_mime_stream_get_type ();
+	g_mime_stream_buffer_get_type ();
+	g_mime_stream_cat_get_type ();
+	g_mime_stream_file_get_type ();
+	g_mime_stream_filter_get_type ();
+	g_mime_stream_fs_get_type ();
+	g_mime_stream_mem_get_type ();
+	g_mime_stream_mmap_get_type ();
+	g_mime_stream_null_get_type ();
+	
+	g_mime_parser_get_type ();
 	g_mime_message_get_type ();
+	g_mime_data_wrapper_get_type ();
 	g_mime_content_type_get_type ();
 	g_mime_content_disposition_get_type ();
 	
@@ -119,6 +150,7 @@ g_mime_init (guint32 flags)
 	internet_address_mailbox_get_type ();
 	
 	/* register our default mime object types */
+	g_mime_object_type_registry_init ();
 	g_mime_object_register_type ("*", "*", g_mime_part_get_type ());
 	g_mime_object_register_type ("multipart", "*", g_mime_multipart_get_type ());
 	g_mime_object_register_type ("multipart", "encrypted", g_mime_multipart_encrypted_get_type ());
@@ -142,6 +174,7 @@ g_mime_shutdown (void)
 	if (--initialized)
 		return;
 	
+	g_mime_object_type_registry_shutdown ();
 	g_mime_charset_map_shutdown ();
 	g_mime_iconv_shutdown ();
 }
